var hierarchy =
[
    [ "Accessor", "classtvg_1_1Accessor.html", null ],
    [ "Animation", "classtvg_1_1Animation.html", null ],
    [ "Canvas", "classtvg_1_1Canvas.html", [
      [ "GlCanvas", "classtvg_1_1GlCanvas.html", null ],
      [ "SwCanvas", "classtvg_1_1SwCanvas.html", null ],
      [ "WgCanvas", "classtvg_1_1WgCanvas.html", null ]
    ] ],
    [ "Fill::ColorStop", "structtvg_1_1Fill_1_1ColorStop.html", null ],
    [ "Fill", "classtvg_1_1Fill.html", [
      [ "LinearGradient", "classtvg_1_1LinearGradient.html", null ],
      [ "RadialGradient", "classtvg_1_1RadialGradient.html", null ]
    ] ],
    [ "Initializer", "classtvg_1_1Initializer.html", null ],
    [ "Matrix", "structtvg_1_1Matrix.html", null ],
    [ "Paint", "classtvg_1_1Paint.html", [
      [ "Picture", "classtvg_1_1Picture.html", null ],
      [ "Scene", "classtvg_1_1Scene.html", null ],
      [ "Shape", "classtvg_1_1Shape.html", null ],
      [ "Text", "classtvg_1_1Text.html", null ]
    ] ],
    [ "Point", "structtvg_1_1Point.html", null ],
    [ "Saver", "classtvg_1_1Saver.html", null ]
];